<?php
  include_once(dirname(__FILE__) ."/include/main.php");

  // no user specified - redirect to user list page
  if(!getUser()) 
  {
    $singleUserID = DataAccess::GetSingleUserID();
    if(!$singleUserID) Helper::Redirect("users.php");
    Helper::SetUser(DataAccess::GetUserByID($singleUserID));
  }
  
  // user is hidden - redirect to user list page
  if(!getUser()->Visible) Helper::Redirect("users.php");
  
  $searchCriteria = Session::GetSearchCriteria(getUser()->ID);
  
  if(!isset($searchCriteria))
  {
    // default search criteria  
    $searchCriteria = array(
        "selectedYear" => date("Y"),
        "selectedCategoryID" => getUser()->DefaultCategoryID
    );
  }
  
  if(isset($_POST["year"])) $searchCriteria["selectedYear"] = $_POST["year"];
  if(isset($_POST["categoryID"])) $searchCriteria["selectedCategoryID"] = $_POST["categoryID"];

  $errors = array();
  
  if($_GET["error"] == "thumbnailCreationFailure")
  {
    // calculate max image size for auto-generation of thumbnail
    $memoryLimit = ini_get("memory_limit");
    if(stripos($memoryLimit, "M")) $memoryLimit = ((int)str_replace("M", "", $memoryLimit)) * 1024 * 1024;
    $memoryLimit -= memory_get_usage();
    $size = round(sqrt($memoryLimit / 4) / 100) * 100; 
    $errors[] = sprintf(__("THUMBNAIL_CREATION_FAILURE"), $size. "x". $size);
  }
  
?>
<?php print '<?xml version="1.0" encoding="UTF-8"?>'; ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
  <title><?=__("PAGE_TITLE")?></title>
  <meta http-equiv="Content-Type" content="text/html;charset=UTF-8" />
  <link rel="icon" type="image/png" href="gfx/favicon.png" />
  <link rel="stylesheet" href="style.css" type="text/css" />
  <link rel="alternate" type="application/rss+xml" title="RSS" href="rss.php?<?=Helper::CreateQuerystring(getUser())?>" />
  <script type="text/javascript" src="js/prototype/prototype_1.6.0.3.js"></script>
  <script type="text/javascript">
    function toggleComment(id)
    {
      $('shortComment_' + id).toggleClassName('hidden');
      $('longComment_' + id).toggleClassName('hidden');
    }
    
    function submitForm()
    {
      document.forms[0].submit();
    }
    
  </script>
</head>

<body id="indexBody">
<div id="wrapper">
<? Helper::CreateTopbar() ?>
<div id="content">
<form method="post" action="<?=$_SERVER["PHP_SELF"]?>?<?=Helper::CreateQuerystring(getUser())?>">
<? if(count($errors) > 0) { ?>
<ul class="error">
<?
  foreach($errors as $e)
  {
    print "<li>$e</li>";
  }
?>
</ul>
<? } ?>

<div>
  <img id="logo" src="gfx/book.png" alt="" />
</div>

<div id="rssIcon"><a href="rss.php?<?=Helper::CreateQuerystring(getUser())?>"><img src="gfx/feed-icon-28x28.png" alt="<?=__("RSS_FEED")?>" title="<?=__("RSS_FEED")?>" /></a></div>

<div id="intro">
<h1><?=__("CAPTION")?></h1>
<p><?=nl2br(__("INTRO"))?></p>

<div id="selectCategoryAndYear"><div class="inner1"><div class="inner2"><div class="inner3">
<? 
  // get all categories
  $allCategoriesItem = new Category();
  $allCategoriesItem->ID = 0;
  $allCategoriesItem->Name = __("ALL_CATEGORIES");
  $categories = DataAccess::GetCategoriesByUserID(getUser()->ID);
  $categoriesWithText = array_merge(array(0 => $allCategoriesItem), $categories);

  // get all years
  $years = DataAccess::GetYearsByUserID(getUser()->ID);
  $years = array_reverse($years);
  $yearsWithText[0] = array("value" => 0, "text" => __("ALL_YEARS"));
  foreach($years as $year)
  {
    $yearsWithText[$year] = array("value" => $year, "text" => $year);
  }
  if(!in_array($searchCriteria["selectedYear"], array_keys($yearsWithText))) $searchCriteria["selectedYear"] = $years[0];
  if(!in_array($searchCriteria["selectedCategoryID"], array_keys($categories))) $searchCriteria["selectedCategoryID"] = $categories[0];
  
  if(count($years) == 0)
  {
    print __("NO_MAPS");
  }
  else
  {
  ?>  
  <label for="categoryID"><?=__("SELECT_CATEGORY")?>:</label>
  <select name="categoryID" id="categoryID" onchange="submitForm();">
  <?
    foreach($categoriesWithText as $category)
    {
      print '<option value="'. $category->ID .'"'. ($searchCriteria["selectedCategoryID"] == $category->ID? ' selected="selected"' : '') .'>'. $category->Name .'</option>';
    }
  ?>
  </select>
  <label for="year"><?=__("SELECT_YEAR")?>:</label>
  <select name="year" id="year" onchange="submitForm();">
  <?
    foreach($yearsWithText as $year)
    {
      print '<option value="'. $year["value"] .'"'. ($searchCriteria["selectedYear"] == $year["value"] ? ' selected="selected"' : '') .'>'. $year["text"] .'</option>';
    }
  ?>
  </select>
<? } ?>
</div></div></div></div>
</div>

<div id="maps">
<?
  $startDate = ($searchCriteria["selectedYear"] == 0 ? 0 : strtotime($searchCriteria["selectedYear"] ."-01-01"));
  $endDate = ($searchCriteria["selectedYear"] == 0 ? 0 : strtotime($searchCriteria["selectedYear"]. "-12-31"));

  $maps = DataAccess::GetMaps(getUser()->ID, $startDate, $endDate, $searchCriteria["selectedCategoryID"]);
  
  $width = THUMBNAIL_WIDTH;
  $height = THUMBNAIL_HEIGHT;
  
  if(count($maps) == 0 && count($years) > 0) print '<p class="clear">'. __("NO_MATCHING_MAPS") .'</p>';
  
  foreach($maps as $map)
  {
    $url = ($map->MapImage ? 'show_map.php?'. Helper::CreateQuerystring(getUser(), $map->ID) : "");
    $name = $map->Name .' ('. date(__("DATE_FORMAT"), strtotime($map->Date)) .')';
    $image = '<img src="'. Helper::GetThumbnailImage($map) .'" alt="'. $name  .'" height="'. $height .'" width="'. $width .'" />';
    $linkedName = Helper::EncapsulateLink($map->Name, $url); 
    $linkedImage = Helper::EncapsulateLink($image, $url); 
    $atoms = array();
    if(__("SHOW_MAP_AREA_NAME") && $map->MapName) $atoms[] = $map->MapName;
    if(__("SHOW_ORGANISER") && $map->Organiser) $atoms[] = $map->Organiser;
    if(__("SHOW_COUNTRY") && $map->Country) $atoms[] = $map->Country;
    $mapAreaOrganiserCountry = join(", ", $atoms); 
?>
 
  <div class="map">
    <div class="inner">
      <div class="thumbnail">
        <?=$linkedImage?>
      </div>
      <div class="info">
        <div class="date">
          <?=Helper::DateToLongString(strtotime($map->Date))?>
        </div>
        <div class="name">
          <?=$linkedName?>
        </div>
        <? if(__("SHOW_MAP_AREA_NAME") || __("SHOW_ORGANISER") || __("SHOW_COUNTRY")) { ?>
        <? if($searchCriteria["selectedCategoryID"] == 0) print '<div class="category">'. __("CATEGORY") .": ". $categories[$map->CategoryID]->Name .'</div>'; ?>
        <div class="organiser">
          <?=$mapAreaOrganiserCountry?>
        </div>
        <? } ?>
        <? if(__("SHOW_DISCIPLINE")) { ?>
        <div class="discipline">
          <?=$map->Discipline?><? if(__("SHOW_RELAY_LEG") && $map->RelayLeg) print ', '. __("RELAY_LEG_LOWERCASE") .' '. $map->RelayLeg; ?>
        </div>
        <? } ?>
        <? if(__("SHOW_RESULT_LIST_URL") && $map->CreateResultListUrl()) { ?>
        <div class="resultListUrl">
          <a href="<?=$map->CreateResultListUrl()?>"><?=__("RESULTS")?></a>
        </div>
        <? } ?>
        <? if(Helper::IsLoggedInUser() && Helper::GetLoggedInUser()->ID == getUser()->ID) { ?>
          <div class="admin">
            <?=$map->Views?> <?=__("VIEWS")?> <span class="separator">|</span> <a href="edit_map.php?<?=Helper::CreateQuerystring(getUser(), $map->ID)?>"><?=__("EDIT_MAP")?></a>
          </div>
        <? } ?>
      </div>
      <? 
        if(__("SHOW_COMMENT")) 
        {
          createComment($map);
        }
        ?>
      <div class="clear"></div>
    </div>
  </div>

<?
  }
?>
  </div>
<div class="clear"></div>

<p id="footer"><?=__("FOOTER")?></p>

</form>
</div>
</div>
</body>
</html>
<?

  Session::SetSearchCriteria(getUser()->ID, $searchCriteria);

  function createComment($map)
  {
    if(!$map->Comment) return;
    $maxLength = 130;
    
    $strippedComment = strip_tags($map->Comment);
    
    if($strippedComment == $map->Comment && strlen($map->Comment) <= $maxLength)
    {
      print '<div class="comment">'. $map->Comment .'</div>';
    }
    else
    {
      ?>
      <div class="comment" id="shortComment_<?=$map->ID?>">
        <img src="gfx/plus.png" class="button" onclick="toggleComment(<?=$map->ID?>);" alt="" />
        <div class="indent"><?=substr($strippedComment, 0, $maxLength)?>...</div>
      </div>
      <div class="comment hidden" id="longComment_<?=$map->ID?>">
        <img src="gfx/minus.png" class="button" onclick="toggleComment(<?=$map->ID?>);" alt="" />
        <div class="indent"><?=nl2br($map->Comment)?></div>
      </div>
      <?
    }
  }
?>